@@ -2,6 +2,8 @@
 from decorated.base.function import Function
 import time
 
+ENABLED = True
+
 class Retries(Function):
     def _init(self, times, delay=0):
         if times <= 0:
@@ -10,6 +12,9 @@ class Retries(Function):
         self._delay = delay
         
     def _call(self, *args, **kw):
+        if not ENABLED:
+            return super(Retries, self)._call(*args, **kw)
+        
         for i in range(self._times):
             try:
                 return super(Retries, self)._call(*args, **kw)
